@@ -1,3 +1,7 @@
+class ConnectionError(Exception):
+    """We could not connect to the writer."""
+    pass
+
 class ProtocolViolationException(Exception):
     """The writer did something unexpected"""
     pass
